//-----------------------------------------------------------------------------
//    M41T00 software library
//-----------------------------------------------------------------------------
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//-----------------------------------------------------------------------------
#include "board.h"
#include "lib_twi.h"
#include "M41T00.h"
//-----------------------------------------------------------------------------
// Convert decimal value to BCD value
//-----------------------------------------------------------------------------
unsigned char DecToBCD(unsigned char Dec)
{
	return (((Dec / 10) << 4) | (Dec % 10));
}
//-----------------------------------------------------------------------------
// Convert BCD value to decimal value
//-----------------------------------------------------------------------------
unsigned char BCDToDec(unsigned char BCD)
{
	return ((BCD >> 4) * 10) + (BCD & 0xF);
}
//-----------------------------------------------------------------------------
// Write to RTC register
//-----------------------------------------------------------------------------
void M41T00_Init(void)
{
AT91F_TWI_Open(100000);
}
//-----------------------------------------------------------------------------
// Write to RTC register
//-----------------------------------------------------------------------------
void M41T00_WriteReg(unsigned char addr, unsigned char value)
{
AT91F_TWI_WriteSingleIadr(AT91C_BASE_TWI, 0x68 << 16, addr, AT91C_TWI_IADRSZ_1_BYTE, &value); 
}
//-----------------------------------------------------------------------------
// Read from RTC register
//-----------------------------------------------------------------------------
unsigned char M41T00_ReadReg(unsigned char addr)
{
char dane;
while(AT91F_TWI_ReadSingleIadr(AT91C_BASE_TWI, 0x68 << 16,  addr, AT91C_TWI_IADRSZ_1_BYTE, &dane));
return dane;
}
//-----------------------------------------------------------------------------
// Write date and time to RTC
//-----------------------------------------------------------------------------
void M41T00_SetDateTime(DateTime*  DT)
{
	M41T00_WriteReg(M41T00_SECONDS, DecToBCD(DT->Seconds));
	M41T00_WriteReg(M41T00_MINUTES, DecToBCD(DT->Minutes));
	M41T00_WriteReg(M41T00_HOURS, 	DecToBCD(DT->Hours));
	M41T00_WriteReg(M41T00_DOW, 	DecToBCD(DT->DayOfWeek));
	M41T00_WriteReg(M41T00_DAY, 	DecToBCD(DT->Day));
	M41T00_WriteReg(M41T00_MONTH, 	DecToBCD(DT->Month));
	M41T00_WriteReg(M41T00_YEAR, 	DecToBCD(DT->Year));
}
//-----------------------------------------------------------------------------
// Read date and time from RTC
//-----------------------------------------------------------------------------
void M41T00_GetDateTime(DateTime * DT)
{
	DT->Seconds 	= BCDToDec(M41T00_ReadReg(M41T00_SECONDS) & 0x7F);
	DT->Minutes 	= BCDToDec(M41T00_ReadReg(M41T00_MINUTES) & 0x7F);
	DT->Hours 		= BCDToDec(M41T00_ReadReg(M41T00_HOURS) & 0x3F);
	DT->DayOfWeek 	= BCDToDec(M41T00_ReadReg(M41T00_DOW) & 0x7);
	DT->Day 		= BCDToDec(M41T00_ReadReg(M41T00_DAY) & 0x3F);
	DT->Month 		= BCDToDec(M41T00_ReadReg(M41T00_MONTH) & 0x1F);
	DT->Year 		= BCDToDec(M41T00_ReadReg(M41T00_YEAR));
}
//-----------------------------------------------------------------------------
// End of file
//-----------------------------------------------------------------------------
